Boleto bancário

| 237-2 | Recibo do Sacado

Cedente | Agência/Código Cedente 0278-0/0039232-4 | CPF/CNPJ Cedente | Vencimento 05/02/2011
Sacado - CPF/CNPJ: | Nosso Número 06/00002125525-6 | N. do documento 2125525 | Data Documento 18/01/2011
Endereço Cedente - - - - | Valor Documento 8280,00

Demonstrativo
Autenticação Mecânica

| 237-2 | 23790.27804 60000.212559 25003.923205 4 48690000828000

Local de pagamento Pagável Preferencialmente na Rede Bradesco ou Bradesco Expresso. | Vencimento 05/02/2011
Cedente | Agência/Código cedente 0278-0/0039232-4
Data do documento 18/01/2011 | N. do documento 2125525 | Espécie doc | Aceite N | Data processamento 18/01/2011 | Nosso número 06/00002125525-6
Uso do banco | Carteira 06 | Espécie R$ | Quantidade | Valor | (=) Valor documento 8280,00
Instruções (Todas as informações deste bloqueto são de exclusiva responsabilidade do cedente) | (-) Descontos/Abatimentos
(-) Outras deduções
(+) Mora/Multa
(+) Outros acréscimos
(=) Valor cobrado

Sacado | - CPF/CNPJ: - - -
Sacador / Avalista | Código de baixa
| Autenticação Mecânica / Ficha de Compensação